#
# spec file for package libdvdread
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libdvdread
Version:        6.0.0
Release:        lp152.3.6
Summary:        Library for Reading DVD Video Images
License:        GPL-2.0+
Group:          Productivity/Multimedia/Other
Url:            http://www.mplayerhq.hu/
Source0:        http://download.videolan.org/videolan/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:        http://download.videolan.org/videolan/%{name}/%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(openssl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains shared libraries for accessing DVD images (this
package does not contain DeCSS algorithms).

%package -n libdvdread4
Summary:        Library for Reading DVD Video Images
Group:          Productivity/Multimedia/Other
Provides:       %{name} = %{version}
Obsoletes:      %{name} <= 0.9.7

%description -n libdvdread4
This package contains shared libraries for accessing DVD images (this
package does not contain DeCSS algorithms).

%package devel
Summary:        Development Environment for libdvdread
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libdvdread4 = %{version}

%description devel
This package contains the include-files and static libraries for
libdvdread.

%prep
%setup -q

%build
autoreconf -fiv
%configure \
  --disable-static \
  --with-pic
make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
# We install the files on our own, using %%doc
rm -rf %{buildroot}%{_datadir}/doc/libdvdread/

%post   -n libdvdread4 -p /sbin/ldconfig

%postun -n libdvdread4 -p /sbin/ldconfig

%files -n libdvdread4
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%{_libdir}/libdvdread.so.4
%{_libdir}/libdvdread.so.4.*

%files devel
%defattr(-,root,root)
%{_includedir}/dvdread
%{_libdir}/libdvdread.so
%{_libdir}/pkgconfig/dvdread.pc

%changelog
* Sat Jan 27 2018 j.lorenzen@kabelmail.de
- Update to version 6.0.0:
  * restrict the number of symbols to be exposed to the
    shared-object
  * remove dvdinput_error function
  * improve compatibility with some DVDs (notably the eOne ones)
  * fix write after free in ifoFree functions
  * fix possible buffer overflow in open
  * additional checks on DVDReadBytes arguments
  * fix leaks
- Removed libdvdread-no-internal-crypto.patch because it's not
  applied anymore.
* Thu Sep 24 2015 mpluskal@suse.com
- Add gpg signature
- Use more explicit dependencies
- Make build more verbose
- Clenup spec file with spec-cleaner
* Sat Mar 28 2015 joerg.lorenzen@ki.tng.de
- Update to version 5.0.3:
  * Cache IFO and BUP files (only for ImageFiles) in order to reduce
  the number of read/seek access
  * Fix compilation warnings for OS/2
* Fri Jan 30 2015 joerg.lorenzen@ki.tng.de
- Update to version 5.0.2:
  * Add DVDOpenStream to open a dvd from a set of callbacks
* Tue Jan 27 2015 joerg.lorenzen@ki.tng.de
- Update to version 5.0.1:
  * support DragonFly BSD bswap
  * new md5 implementation, under LGPL
  * fix partial reads
  * fix warnings and code cleanup
* Wed Dec 17 2014 joerg.lorenzen@ki.tng.de
- Update to version 5.0.0:
  * added support for Android
  * fix build support for OS/2
  * fix crashes in IFO parsing (Shark Week The Great Bites Collection)
* Fri Jul 18 2014 dimstar@opensuse.org
- Update to version 4.9.9 (5.0 Release Candidate)
  + 3 years worth of development; please see NEWS file in package.
- Drop libdvdread-strict-aliasing.patch: no longer required.
- Move AUTHORS, COPYING, NEWS and README to the library package.
* Tue Jul 31 2012 crrodriguez@opensuse.org
- Use openssl for crypto, we have too many duplicated
  implementations of common digest algos
- Autotools fixes.
* Sat Dec  3 2011 pascal.bleser@opensuse.org
- update to 4.2.0:
  * fixed ARM memory alignment issue
  * added a missing DVDFileStat function
  * exposed the dvd_stat_t struct in header
  * fixed libdvdread closing stdin if it can't open the file/device
  * fixed a segfault in UDFFileEntry on some badly mastered DVDs
  * fixed big-endian builds
  * provide BUP file support for more issues
  * move UDFReadBlocksRaw declaration to dvdread_internal.h
  * fixed double free of parental management information
  * fixed crash when PTT is too short
  * fixed segfault when reading certain DVDs, for example "Thor"
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Wed May 18 2011 davejplater@gmail.com
- Added baselibs.conf. Removed licenses link from spec.
* Thu Jan 27 2011 davejplater@gmail.com
- Added Requires: pkg-config to get the .pc file to build.
* Wed Sep 10 2008 hvogel@suse.de
- update to 4.1.3 fork from mplayer
  * fixes regarding potential memory and resource leaks
  * added dvdread-config
  * added pkgconfig support
* Tue Aug 21 2007 crrodriguez@suse.de
- fix devel package dependencies
- remote static libraries and pointless libtool archive
* Sun Jul 29 2007 ro@suse.de
- provide old name
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 0.9.7:
  * Properly call dvdinput_free().
- Name package according to shared library packaging policy.
* Mon Jun 12 2006 kukuk@suse.de
- Cleanup superfluous BuildRequires
* Mon May 15 2006 stark@suse.de
- update to 0.9.6
  * Various bug fixes
  * Potential memory leak fixes
  * Better error handling
  * Some support for multithreaded apps
  * Added DVDFileStat() call
  * Fixed a missing attribute packed for app_info in audio_attr_t
* Fri Dec 16 2005 stark@suse.de
- adjusted ldconfig invocation
* Tue Oct  4 2005 stark@suse.de
- build with -fno-strict-aliasing
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Mar 24 2003 stark@suse.de
- update to 0.9.4
* Thu Jan 16 2003 nadvornik@suse.cz
- fixed to compile with new gcc
* Fri Aug  9 2002 stark@suse.de
- added Requires to -devel package
* Tue Jun 11 2002 ro@suse.de
- use autoreconf (fixes build on ppc64)
* Tue May 28 2002 stark@suse.de
- update to 0.9.3
* Wed Feb 13 2002 stark@suse.de
- used %%{_libdir}
* Mon Jan 14 2002 stark@suse.de
- bzip2 sources
- fixed dlopen() to work with newer versions
* Mon Jan  7 2002 schwab@suse.de
- Fix warning.
* Wed Jan  2 2002 stark@suse.de
- initial package 0.9.2
